# mobiedantic

[![PyPI - Version](https://img.shields.io/pypi/v/mobiedantic.svg)](https://pypi.org/project/mobiedantic)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mobiedantic.svg)](https://pypi.org/project/mobiedantic)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install mobiedantic
```

## License

`mobiedantic` is distributed under the terms of the [BSD-3-Clause](https://spdx.org/licenses/BSD-3-Clause.html) license.
